@@ -108,7 +108,7 @@ $ipp->setFidelity(); // printing abort if every attribute could not be set on pr
 $ipp->setCharset('utf-8');
 $ipp->setLanguage($language);
 
-$ipp->setAuthentification($user,$password); // username & password 
+$ipp->setAuthentication($user,$password); // username & password 
 
 $j = 0;
 $test = 1;
