@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.8 2008/05/12 05:14:15 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/http_class.php,v 1.10 2008/05/14 23:30:41 harding Exp $
  *
  *
  * Class http_class - Basic http client with "Basic" authorization mechanism.
@@ -100,6 +100,7 @@ class http_class {
     public $status;
     public $window_size = 1400; // chunk size of data
     public $with_exceptions = 0; // compatibility mode for old scripts
+    public $port;
 
     private $default_port = 631;
     private $headers;
@@ -142,7 +143,7 @@ class http_class {
 
     // {{{ Open ($arguments)
     public function Open ($arguments) {
-        
+        $this->connected = false;
         if (!$this->timeout)
             $this->timeout = 30;
         $url = $arguments["URL"];
@@ -161,12 +162,7 @@ class http_class {
         $url = $url[1];
         $url = split("/",preg_replace("#^/{1,}#",'',$url),2);
         $url = $url[0];
-        $url = split(":",$url);
-        $this->default_port = "toto";
-        $port = array_slice($url,-1);
-        $port = $port[0];
-        (preg_match("#[0-9]{2,}#",$port)) ? $port=array_pop($url) : $port=$this->default_port;
-        $url = implode(":",$url);
+        $port = $this->port;
         $error = sprintf(_("Cannot resolve url: %s"),$url);
         $ip = gethostbyname($url);
         $ip = @gethostbyaddr($ip);
@@ -174,7 +170,10 @@ class http_class {
             if ($this->with_exceptions)
                 throw new httpException($error);
             else
+            {
                 trigger_error($error,E_USER_WARNING);
+                return false;
+            }
         if (strstr($url,":")) // we got an ipv6 address
             if (!strstr($url,"[")) // it is not escaped
                 $url = sprintf("[%s]",$url);
@@ -187,10 +186,17 @@ class http_class {
 
         if (!$this->connection)
             if ($this->with_exceptions)
+            {
+                $this->connected = false;
                 throw new httpException($error,$errno);
+            }
             else
+            {
                 trigger_error($error,E_USER_WARNING);
-        $this->connected = 1;
+                $this->connected = false;
+                return $error;
+            }
+        $this->connected = true;
     }
     // }}}
 
@@ -241,7 +247,8 @@ class http_class {
 
     // {{{ ReadReplyHeaders (&$headers)
     public function ReadReplyHeaders (&$headers) {
-        $headers = $this->reply_headers;
+        if ($this->connected)
+            $headers = $this->reply_headers;
     }
     // }}}
 
@@ -254,6 +261,7 @@ class http_class {
 
     // {{{ Close ()
     public function Close () {
+        if (!$this->connected) return;
         fclose ($this->connection);
     }
     // }}}
@@ -266,6 +274,7 @@ class http_class {
 
     // {{{ _StreamRequest ($arguments)
     private function _StreamRequest ($arguments) {
+        if (!$this->connected) return;
         
         $this->status = "";
         $this->reply_headers = array();
@@ -421,7 +430,9 @@ class http_class {
     
     // {{{ _ReadReply ()
     private function _ReadReply () {
-      
+     
+     if (!$this->connected) return;
+
         $this->reply_headers = array();
         $this->reply_body = "";
         
@@ -557,12 +568,13 @@ class http_class {
                 }
             }
 
-            
+        //echo $A1,":",$fields["nonce"],":",$A2,"<br />";    
         $response = md5(md5($A1).":". $fields["nonce"].":" .md5($A2));
-        
-        if (isset($qop) && ($qop == "auth"))
-        $response = md5(md5($A1).":".$fields["nonce"].":".$nc.":".$cnonce.":".$qop.":".$A2);
 
+        if (isset($qop) && ($qop == "auth"))
+        {
+        $response = md5(md5($A1).":".$fields["nonce"].":".$nc.":".$cnonce.":".$qop.":".$A2);
+        }
         
         $auth_scheme = sprintf('Digest username="%s", realm="%s", nonce="%s", uri="%s", response="%s"',
                                 $username,
@@ -571,7 +583,7 @@ class http_class {
                                 $this->arguments["RequestURI"],
                                 $response
                                 );
-        
+        //echo $auth_scheme,"<br />";
         if (isset($algorithm))
             $auth_scheme .= sprintf(', algorithm="%s"',$algorithm);
 
