@@ -3,8 +3,8 @@
 $debug = 0;
 error_reporting(E_ALL|E_STRICT);
 /* printing an utf-8 file */
-require_once('PrintIPP.php'); 
-$ipp = new PrintIPP(); 
+require_once('CupsPrintIPP.php'); 
+$ipp = new CupsPrintIPP(); 
 $ipp->with_exceptions = 1;
 
 //
