@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
- /* @(#) $Header: /sources/phpprintipp/phpprintipp/tiny/PrintIPP.php,v 1.4 2008/05/12 03:59:38 harding Exp $
+ /* @(#) $Header: /sources/phpprintipp/phpprintipp/tiny/PrintIPP.php,v 1.5 2008/05/12 22:15:24 harding Exp $
  *
  * Version: 0.4 
  * Class PrintIPP (Tiny) - Send Basic IPP requests, Get IPP Responses.
@@ -772,11 +772,12 @@ class PrintIPP {
                 $http->html_debug=0;
             }
             
-            $url="http://".$this->host.":".$this->port;
+            $url="http://".$this->host;
             if ($this->ssl)
-                $url="https://".$this->host.":".$this->port;
+                $url="https://".$this->host;
             
             
+            $http->port = $this->port;
             $http->timeout = $this->http_timeout;
             $http->data_timeout= $this->http_data_timeout;
             
@@ -1582,6 +1583,7 @@ class http_class {
     public $status;
     public $window_size = 1400; // chunk size of data
     public $with_exceptions = 0; // compatibility mode for old scripts
+    public $port;
 
     private $default_port = 631;
     private $headers;
@@ -1643,33 +1645,28 @@ class http_class {
         $url = $url[1];
         $url = split("/",preg_replace("#^/{1,}#",'',$url),2);
         $url = $url[0];
-        $url = split(":",$url);
-        $this->default_port = "toto";
-        $port = array_slice($url,-1);
-        $port = $port[0];
-        (preg_match("#[0-9]{2,}#",$port)) ? $port=array_pop($url) : $port=$this->default_port;
-        $url = implode(":",$url);
-        $error = sprintf(_("http_class: Cannot resolve url: %s"),$url);
+        $port = $this->port;
+        $error = sprintf(_("Cannot resolve url: %s"),$url);
         $ip = gethostbyname($url);
         $ip = @gethostbyaddr($ip);
         if (!$ip)
             if ($this->with_exceptions)
-                throw new Exception($error);
+                throw new httpException($error);
             else
                 trigger_error($error,E_USER_WARNING);
         if (strstr($url,":")) // we got an ipv6 address
             if (!strstr($url,"[")) // it is not escaped
                 $url = sprintf("[%s]",$url);
-        $this->connection = fsockopen($transport_type.$url, $port, $errno, $errstr, $this->timeout);
-        $error = sprintf (_('http_class: unable to connect to "%s%s port %s": "%s" (errno %s)'),
+        $this->connection = @fsockopen($transport_type.$url, $port, $errno, $errstr, $this->timeout);
+        $error = sprintf (_('Unable to connect to "%s%s port %s": %s'),
             $transport_type,
             $url,
             $port,
-            $errstr,
-            $errno);
+            $errstr);
+
         if (!$this->connection)
             if ($this->with_exceptions)
-                throw new Exception($error);
+                throw new httpException($error,$errno);
             else
                 trigger_error($error,E_USER_WARNING);
         $this->connected = 1;
